@@ -14,14 +14,12 @@
 
 #include "interfaces/dbusinterfaces.h"
 
-class KDECONNECTINTERFACES_EXPORT PluginModel
-    : public QAbstractListModel
+class KDECONNECTINTERFACES_EXPORT PluginModel : public QAbstractListModel
 {
     Q_OBJECT
     Q_PROPERTY(QString deviceId READ deviceId WRITE setDeviceId)
 
 public:
-
     enum ExtraRoles {
         IconRole = Qt::UserRole + 1,
         IdRole,
@@ -38,22 +36,17 @@ public:
     bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole) override;
     int rowCount(const QModelIndex &parent = QModelIndex()) const override;
     QHash<int, QByteArray> roleNames() const override;
-    void setDeviceId(const QString& deviceId);
+    void setDeviceId(const QString &deviceId);
     QString deviceId();
 
 Q_SIGNALS:
-    void deviceIdChanged(const QString& value);
+    void deviceIdChanged(const QString &value);
     void rowsChanged();
 
-
 private:
     QVector<KPluginMetaData> m_plugins;
     QString m_deviceId;
     KSharedConfigPtr m_config;
-
 };
 
-
 #endif // KPLUGINSELECTOR_P_H
-
-
